Skip to contents

Downloads and installs the official iconify extension to the project directory if icons are detected in the dashboard.

Usage

.install_iconify_extension(output_dir)

Arguments

output_dir

The dashboard output directory

Value

Logical indicating if installation was successful