Skip to contents

Adds input filter CSS and JavaScript to enable interactive filtering of Highcharts visualizations via multi-select dropdowns. Uses Choices.js for a polished multi-select experience.

Usage

enable_inputs(linked = FALSE, show_when = FALSE, url_params = FALSE)

Arguments

linked

If TRUE, also include script for linked (cascading) parent-child select inputs. Set automatically when the page uses add_linked_inputs().

show_when

If TRUE, also include script for conditional viz visibility (show_when in add_viz()). Set automatically when the page uses it.

url_params

If TRUE, also include script for URL parameter support.

Value

HTML tags to include input filter functionality

Examples

if (FALSE) { # \dontrun{
# In your dashboard page content:
enable_inputs()
enable_inputs(linked = TRUE)  # when using add_linked_inputs()
enable_inputs(show_when = TRUE)  # when using show_when in add_viz()
} # }