Add a leaflet map to the dashboard
add_leaflet.RdConvenience wrapper around add_widget for leaflet objects.
Usage
add_leaflet(
content,
map,
title = NULL,
height = NULL,
tabgroup = NULL,
filter_vars = NULL,
show_when = NULL
)Arguments
- content
A content_collection, page_object, or dashboard_project
- map
A leaflet object (created with
leaflet::leaflet())- title
Optional title displayed above the map
- height
Optional CSS height
- tabgroup
Optional tabgroup for organizing content
- filter_vars
Optional character vector of input filter variables to apply to this block.
- show_when
One-sided formula controlling conditional display based on input values.