Install iconify extension automatically
dot-install_iconify_extension.RdDownloads and installs the official iconify extension to the project directory if icons are detected in the dashboard.
dot-install_iconify_extension.RdDownloads and installs the official iconify extension to the project directory if icons are detected in the dashboard.