Enable Input Filter Functionality
enable_inputs.RdAdds input filter CSS and JavaScript to enable interactive filtering of Highcharts visualizations via multi-select dropdowns. Uses Choices.js for a polished multi-select experience.
Arguments
- linked
If TRUE, also include script for linked (cascading) parent-child select inputs. Set automatically when the page uses
add_linked_inputs().- show_when
If TRUE, also include script for conditional viz visibility (
show_wheninadd_viz()). Set automatically when the page uses it.- url_params
If TRUE, also include script for URL parameter support.