Create a single visualization specification
spec_viz.RdHelper function to create individual viz specs that can be combined into a list or used directly in add_page().
Examples
if (FALSE) { # \dontrun{
viz1 <- spec_viz(type = "heatmap", x_var = "party", y_var = "ideology")
viz2 <- spec_viz(type = "histogram", x_var = "age")
page_viz <- list(viz1, viz2)
} # }